@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Search YouTube
 
-our $VERSION = '0.0102';
+our $VERSION = '0.0200';
 
 use Moo;
 use strictures 2;
@@ -37,17 +37,12 @@ has ua => (
 sub search {
     my ( $self, %args ) = @_;
 
-    $args{query} = {
-        %{ $args{query} },
-        part => 'snippet',
-        key  => $self->key,
-    };
-
-    my $url = Mojo::URL->new($self->base . '/search');
-
-    if ( $args{query} ) {
-        $url->query(%{ $args{query} });
-    }
+    my $url = Mojo::URL->new($self->base . '/search')
+        ->query(
+            %args,
+            part => 'snippet',
+            key  => $self->key,
+        );
 
     my $tx = $self->ua->get($url);
 
@@ -93,7 +88,7 @@ WebService::YTSearch - Search YouTube
 
 =head1 VERSION
 
-version 0.0102
+version 0.0200
 
 =head1 SYNOPSIS
 
@@ -136,7 +131,10 @@ Create a new C<WebService::YTSearch> object.
 
   $r = $w->search(%arguments);
 
-Fetch the results given the B<query> arguments.
+Fetch the results given the B<arguments>.
+
+For the accepted arguments, please see the YouTube reference link
+below (the main one being C<q>).
 
 =head1 SEE ALSO
 
@@ -162,7 +160,7 @@ Gene Boggs <gene@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2020 by Gene Boggs.
+This software is copyright (c) 2021 by Gene Boggs.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
